# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class LogEntryEditInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item_id': 'int',
        'log_entry': 'str',
        'effective_date': 'datetime'
    }

    attribute_map = {
        'item_id': 'itemId',
        'log_entry': 'logEntry',
        'effective_date': 'effectiveDate'
    }

    def __init__(self, item_id=None, log_entry=None, effective_date=None, local_vars_configuration=None):  # noqa: E501
        """LogEntryEditInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item_id = None
        self._log_entry = None
        self._effective_date = None
        self.discriminator = None

        if item_id is not None:
            self.item_id = item_id
        if log_entry is not None:
            self.log_entry = log_entry
        if effective_date is not None:
            self.effective_date = effective_date

    @property
    def item_id(self):
        """Gets the item_id of this LogEntryEditInformation.  # noqa: E501


        :return: The item_id of this LogEntryEditInformation.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this LogEntryEditInformation.


        :param item_id: The item_id of this LogEntryEditInformation.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def log_entry(self):
        """Gets the log_entry of this LogEntryEditInformation.  # noqa: E501


        :return: The log_entry of this LogEntryEditInformation.  # noqa: E501
        :rtype: str
        """
        return self._log_entry

    @log_entry.setter
    def log_entry(self, log_entry):
        """Sets the log_entry of this LogEntryEditInformation.


        :param log_entry: The log_entry of this LogEntryEditInformation.  # noqa: E501
        :type: str
        """

        self._log_entry = log_entry

    @property
    def effective_date(self):
        """Gets the effective_date of this LogEntryEditInformation.  # noqa: E501


        :return: The effective_date of this LogEntryEditInformation.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this LogEntryEditInformation.


        :param effective_date: The effective_date of this LogEntryEditInformation.  # noqa: E501
        :type: datetime
        """

        self._effective_date = effective_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogEntryEditInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LogEntryEditInformation):
            return True

        return self.to_dict() != other.to_dict()
